@@ -83,13 +83,16 @@ sub run {
     my $name = "Group: " . $self->name;
     my $debug = $instance->can('FENNEC') && $instance->FENNEC->debug;
 
+    return $meta->skip->( $name, $self->skip )
+        if $self->skip;
+
     my $ref = ref $self;
     $ref =~ s/^.*:://;
     if ($debug) {
         my $collector = Fennec::Runner->new->collector;
         my ($sec, $ms) = Time::HiRes::gettimeofday();
         my $msg = sprintf(
-            "FENNEC_DEBUG_BLOCK:PID:%d\0START_LINE:%d\0END_LINE:%d\0TYPE:%s\0NAME:%s\0SEC:%d\0MSEC:%d\n",
+            "FENNEC_DEBUG_BLOCK:PID:%d\0START_LINE:%d\0END_LINE:%d\0TYPE:%s\0NAME:%s\0SEC:%d\0MSEC:%d\0STATE:START\n",
             $$,
             $self->start_line,
             $self->end_line,
@@ -101,9 +104,6 @@ sub run {
         $collector->diag($msg);
     }
 
-    return $meta->skip->( $name, $self->skip )
-        if $self->skip;
-
     $meta->todo_start->( $self->todo )
         if $self->todo;
 
@@ -114,6 +114,22 @@ sub run {
     $meta->todo_end->()
         if $self->todo;
 
+    if ($debug) {
+        my $collector = Fennec::Runner->new->collector;
+        my ($sec, $ms) = Time::HiRes::gettimeofday();
+        my $msg = sprintf(
+            "FENNEC_DEBUG_BLOCK:PID:%d\0START_LINE:%d\0END_LINE:%d\0TYPE:%s\0NAME:%s\0SEC:%d\0MSEC:%d\0STATE:END\n",
+            $$,
+            $self->start_line,
+            $self->end_line,
+            $self->subtype,
+            $self->name,
+            $sec,
+            $ms,
+        );
+        $collector->diag($msg);
+    }
+
     return if $success && !$self->verbose;
 
     $meta->ok->( $success || 0, $name );
